OptionGreeks

Trait OptionGreeks 

pub trait OptionGreeks {
Show 17 methods // Provided methods fn delta<T: Option>(&self, option: &T) -> f64 { ... } fn vega<T: Option>(&self, option: &T) -> f64 { ... } fn theta<T: Option>(&self, option: &T) -> f64 { ... } fn rho<T: Option>(&self, option: &T) -> f64 { ... } fn lambda<T: Option>(&self, option: &T) -> f64 { ... } fn epsilon<T: Option>(&self, option: &T) -> f64 { ... } fn gamma<T: Option>(&self, option: &T) -> f64 { ... } fn vanna<T: Option>(&self, option: &T) -> f64 { ... } fn charm<T: Option>(&self, option: &T) -> f64 { ... } fn vomma<T: Option>(&self, option: &T) -> f64 { ... } fn veta<T: Option>(&self, option: &T) -> f64 { ... } fn vera<T: Option>(&self, option: &T) -> f64 { ... } fn speed<T: Option>(&self, option: &T) -> f64 { ... } fn zomma<T: Option>(&self, option: &T) -> f64 { ... } fn color<T: Option>(&self, option: &T) -> f64 { ... } fn ultima<T: Option>(&self, option: &T) -> f64 { ... } fn parmicharma<T: Option>(&self, option: &T) -> f64 { ... }
}
Trait for calculating the Greeks of an option.

Provided Methods

fn delta<T: Option>(&self, option: &T) -> f64

Delta measures the rate of change of the option price with respect to changes in the price of the underlying asset.

fn vega<T: Option>(&self, option: &T) -> f64

Vega measures the rate of change of the option price with respect to changes in the volatility of the underlying asset.

fn theta<T: Option>(&self, option: &T) -> f64

Theta measures the rate of change of the option price with respect to changes in time to maturity.

fn rho<T: Option>(&self, option: &T) -> f64

Rho measures the rate of change of the option price with respect to changes in the risk-free interest rate.

fn lambda<T: Option>(&self, option: &T) -> f64

Lambda measures the rate of change of the option delta with respect to changes in the risk-free interest rate.

fn epsilon<T: Option>(&self, option: &T) -> f64

Epsilon measures the rate of change of the option delta with respect to changes in the dividend yield.

fn gamma<T: Option>(&self, option: &T) -> f64

Gamma measures the rate of change of the option delta with respect to changes in the price of the underlying asset.

fn vanna<T: Option>(&self, option: &T) -> f64

Vanna measures the rate of change of the option delta with respect to changes in the volatility of the underlying asset.

fn charm<T: Option>(&self, option: &T) -> f64

Charm measures the rate of change of the option delta with respect to changes in time to maturity.

fn vomma<T: Option>(&self, option: &T) -> f64

Vomma measures the rate of change of the option vega with respect to changes in the volatility of the underlying asset.

fn veta<T: Option>(&self, option: &T) -> f64

Veta measures the rate of change of the option vega with respect to changes in time to maturity.

fn vera<T: Option>(&self, option: &T) -> f64

Vera measures the rate of change of the option gamma with respect to changes in the volatility of the underlying asset.

fn speed<T: Option>(&self, option: &T) -> f64

Speed measures the rate of change of the option gamma with respect to changes in the price of the underlying asset.

fn zomma<T: Option>(&self, option: &T) -> f64

Zomma measures the rate of change of the option gamma with respect to changes in the volatility of the underlying asset.

fn color<T: Option>(&self, option: &T) -> f64

Color measures the rate of change of the option gamma with respect to changes in time to maturity.

fn ultima<T: Option>(&self, option: &T) -> f64

Ultima measures the rate of change of the option vomma with respect to changes in the volatility of the underlying asset.

fn parmicharma<T: Option>(&self, option: &T) -> f64

Parmicharma measures the rate of change of charm over the passage of time.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors